@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 
 from __future__ import absolute_import
-from __future__ import with_statement
 
 #
 # Unit tests for the multiprocessing package
@@ -21,7 +20,7 @@ from test import test_support
 from StringIO import StringIO
 try:
     from billiard._ext import _billiard
-except ImportError, exc:
+except ImportError as exc:
     raise SkipTest(exc)
 # import threading after _billiard to raise a more revelant error
 # message: "No module named _billiard". _billiard is not compiled
@@ -31,7 +30,7 @@ import threading
 # Work around broken sem_open implementations
 try:
     import billiard.synchronize
-except ImportError, exc:
+except ImportError as exc:
     raise SkipTest(exc)
 
 import billiard.dummy
@@ -946,9 +945,9 @@ class _TestContainers(BaseTestCase):
         indices = range(65, 70)
         for i in indices:
             d[i] = chr(i)
-        self.assertEqual(d.copy(), dict((i, chr(i)) for i in indices))
+        self.assertEqual(d.copy(), dict((j, chr(j)) for j in indices))
         self.assertEqual(sorted(d.keys()), indices)
-        self.assertEqual(sorted(d.values()), [chr(j) for j in indices])
+        self.assertEqual(sorted(d.values()), [chr(z) for z in indices])
         self.assertEqual(sorted(d.items()), [(x, chr(x)) for x in indices])
 
     def test_namespace(self):
@@ -1093,8 +1092,8 @@ class _TestZZZNumberOfObjects(BaseTestCase):
         refs = self.manager._number_of_objects()
         debug_info = self.manager._debug_info()
         if refs != EXPECTED_NUMBER:
-            print self.manager._debug_info()
-            print debug_info
+            print(self.manager._debug_info())
+            print(debug_info)
 
         self.assertEqual(refs, EXPECTED_NUMBER)
 
@@ -1313,8 +1312,8 @@ class _TestConnection(BaseTestCase):
             self.assertEqual(conn.send_bytes(longmsg), None)
             try:
                 res = conn.recv_bytes_into(buffer)
-            except billiard.BufferTooShort, e:
-                self.assertEqual(e.args, (longmsg,))
+            except billiard.BufferTooShort as exc:
+                self.assertEqual(exc.args, (longmsg,))
             else:
                 self.fail('expected BufferTooShort, got %s' % res)
 
